@@ -1068,7 +1068,7 @@ class Viewer(object):
     p.stdin.write(data_in)
 
     stdout = p.communicate()[0]
-    self.read_and_display(stdout.split("\n"))
+    self.read_and_display([stdout])
 
   def find_and_focus(self, word=None, reverse=False):
     start_index = 0
